@@ -1,6 +1,6 @@
 // Filename: isa.rs
-// Version:	 0.4
-// Date:	 27-10-2021 (DD-MM-YYYY)
+// Version:	 0.5
+// Date:	 25-01-2022 (DD-MM-YYYY)
 // Library:  gpcas_isa
 //
 // Copyright (c) 2021 Kai Rese
@@ -37,10 +37,17 @@ pub struct Isa {
     pub emulator: Box<dyn Emulator>,
     /// How the ISA handles memory accesses.
     pub memory_access_type: MemoryAccessType,
-    /// How many registers there are per bank.
+    /// The amount of general purpose registers accessible through the ISA.
+    pub general_purpose_register_count: usize,
+    /// The amount of vector registers accessible through the ISA.
+    pub vector_register_count: usize,
+    /// The amount of special registers accessible through the ISA.
+    pub special_register_count: usize,
+    /// The minimum alignment of an instruction word in power-of-two bytes.
     ///
-    /// General purpose, vector and special registers each have their own bank.
-    pub register_bank_size: usize,
+    /// This is equivalent to how many least significant bits of the instruction address always
+    /// stay zero.
+    pub instruction_word_alignment: usize,
 }
 
 /// Identifiers of all ISAs recognized by the simulator.
